ams.core.service.ZonalSum
=========================

.. currentmodule:: ams.core.service

.. autoclass:: ZonalSum

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~ZonalSum.assign_memory
       
       
          ~ZonalSum.evaluate
       
       
          ~ZonalSum.get_names
       
       
          ~ZonalSum.parse
       
       
          ~ZonalSum.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~ZonalSum.class_name
      ~ZonalSum.n
      ~ZonalSum.shape
      ~ZonalSum.size
      ~ZonalSum.v
      ~ZonalSum.v0
      ~ZonalSum.v1
   
   